import requests


class WallabagClient:
    """
    A client to interact with the Wallabag API using OAuth2 for authentication.

    This class handles authentication and sending requests to the API endpoints.
    ----------
    Attributes

    client_id : str
        The client ID for OAuth2 authentication.
    client_secret : str
        The client secret for OAuth2 authentication.
    username : str
        The username of the Wallabag account.
    password : str
        The password of the Wallabag account.
    base_url : str
        The base URL of the Wallabag instance.
    token : str
        The access token obtained from the OAuth2 authentication.
    """

    def __init__(
        self,
        client_id,
        client_secret,
        username,
        password,
        base_url="https://app.wallabag.it",
    ):
        """
        Initializes the WallabagClient with user credentials and OAuth2 tokens.

        ----------
        Parameters

        client_id : str
            The client ID for OAuth2 authentication.
        client_secret : str
            The client secret for OAuth2 authentication.
        username : str
            The username of the Wallabag account.
        password : str
            The password of the Wallabag account.
        base_url : str, optional
            The base URL of the Wallabag instance (default is "https://app.wallabag.it").
        """
        self.client_id = client_id
        self.client_secret = client_secret
        self.username = username
        self.password = password
        self.base_url = base_url
        self.token = self.authenticate()

    def authenticate(self):
        """
        Authenticates the user and retrieves the access token using OAuth2.

        ----------
        Returns

        str
            The access token for making authenticated API requests.

        ----------
        Raises

        requests.exceptions.HTTPError
            If the authentication request fails.
        """
        auth_url = f"{self.base_url}/oauth/v2/token"
        data = {
            "grant_type": "password",
            "client_id": self.client_id,
            "client_secret": self.client_secret,
            "username": self.username,
            "password": self.password,
        }
        response = requests.post(auth_url, data=data)
        response.raise_for_status()
        token_info = response.json()
        return token_info["access_token"]

    def make_request(self, method, endpoint, params=None, data=None):
        """
        Makes a request to the Wallabag API with the given parameters.

        ----------
        Parameters

        method : str
            The HTTP method (GET, POST, DELETE, etc.).
        endpoint : str
            The API endpoint (e.g., 'entries.json').
        params : dict, optional
            The query parameters to include in the request.
        data : dict, optional
            The data to send with the request (for POST, PUT, etc.).

        ----------
        Returns

        dict
            The response from the API as a dictionary.

        ----------
        Raises

        requests.exceptions.HTTPError
            If the request fails.
        """
        headers = {
            "Authorization": f"Bearer {self.token}",
            "Content-Type": "application/json",
        }
        url = f"{self.base_url}/api/{endpoint}"
        response = requests.request(
            method, url, headers=headers, params=params, json=data
        )
        response.raise_for_status()
        return response.json()
