class EntriesAPI:
    """
    A class to interact with the Wallabag API for managing entries (articles).

    ----------
    Attributes

    client : WallabagClient
        The client instance to send API requests.
    """

    def __init__(self, client):
        """
        Initializes the EntriesAPI with the WallabagClient.

        ----------
        Parameters

        client : WallabagClient
            The WallabagClient instance to send requests.
        """
        self.client = client

    def get_entries(self, page=1, per_page=30):
        """
        Retrieves a paginated list of entries (articles).

        ----------
        Parameters

        page : int, optional
            The page number to retrieve (default is 1).
        per_page : int, optional
            The number of entries per page (default is 30).

        ----------
        Returns

        dict
            The list of entries and pagination info.
        """
        params = {"page": page, "perPage": per_page}
        return self.client.make_request("GET", "entries.json", params=params)

    def add_entry(self, url):
        """
        Adds a new entry to Wallabag by providing a URL.

        ----------
        Parameters
        ----------
        url : str
            The URL of the article to add.

        ----------
        Returns

        dict
            The details of the newly added entry.
        """
        data = {"url": url}
        return self.client.make_request("POST", "entries.json", data=data)

    def delete_entry(self, entry_id):
        """
        Deletes an entry from Wallabag by its entry ID.

        ----------
        Parameters

        entry_id : int
            The ID of the entry to delete.

        ----------
        Returns

        dict
            The response from the API after deleting the entry.
        """
        return self.client.make_request("DELETE", f"entries/{entry_id}.json")

    def get_entry(self, entry_id):
        """
        Retrieves the details of a specific entry by its ID.

        ----------
        Parameters

        entry_id : int
            The ID of the entry to retrieve.

        ----------
        Returns

        dict
            The details of the specified entry.
        """
        return self.client.make_request("GET", f"entries/{entry_id}.json")
